<template>
  <a-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    @ok="handleOk"
    @cancel="handleCancel"
  >
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :label-col="labelCol" :wrapper-col="wrapperCol" :model="model" :rules="validatorRules">
        <!-- 主表单区域 -->
        <a-row class="form-row" :gutter="16">
          <a-col :lg="24">
            <a-form-model-item label="专利(软著)名称" prop="mc">
              <a-input v-model="model.mc" placeholder="请输入专利(软著)名称" />
            </a-form-model-item>
          </a-col>

          <a-col :lg="24">
            <a-form-model-item label="专利(软著)编号" prop="bh">
              <a-input v-model="model.bh" placeholder="请输入专利(软著)编号" />
            </a-form-model-item>
          </a-col>

          <a-col :lg="24">
            <a-form-model-item label="负责人" prop="fzr">
              <j-select-user-by-dep
                placeholder="请选择专利(软著)负责人"
                @ids="(v) => handleChangeUserCommon(v)"
                v-model="model.fzr"
                :multi="true"
                :trigger-change="false"
              ></j-select-user-by-dep>
            </a-form-model-item>
          </a-col>

          <a-col :lg="24">
            <a-form-model-item label="专利(软著)成员" prop="xgcy">
              <j-select-user-by-dep
                placeholder="请选择专利(软著)成员"
                @ids="(v) => handleChangeUserCommon(v)"
                v-model="model.xgcy"
                :multi="true"
                :trigger-change="false"
              ></j-select-user-by-dep>
            </a-form-model-item>
          </a-col>


          <a-col :lg="24">
            <a-form-model-item label="类型" prop="type">
              <j-dict-select-tag v-model="model.type" title="项目类型" dictCode="patent_type" placeholder="请选择类型" />
            </a-form-model-item>
          </a-col>
          <a-col :lg="24">
            <a-form-model-item label="申请日期" >
          <a-date-picker
            style="width: 100%"
            placeholder="请选择申请日期"
            v-model="model.sqrq"
            format="YYYY-MM-DD"
            />
            </a-form-model-item>
          </a-col>
          <a-col :lg="24">
            <a-form-model-item label="描述">
              <a-textarea v-model="model.ms" placeholder="请输入描述" />
            </a-form-model-item>
          </a-col>


        </a-row>
      </a-form-model>
    </a-spin>

    <!--   选择用户  -->
  </a-modal>
</template>

<script>
import JSelectUserByDepModal from '@/components/jeecgbiz/modal/JSelectUserByDepModal'
import { httpAction, getAction, postAction, putAction } from '@/api/manage'

export default {
  name: 'PaSoftbookModal',
  components: {
    JSelectUserByDepModal,
  },
  data() {
    return {
      title: '新增',
      visible: false,
      form: this.$form.createForm(this),
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      validatorRules: {
        mc: [{ required: true, message: '专利(软著)名称不能为空', trigger: 'blur' }],
        bh: [{ required: true, message: '专利(软著)编号不能为空', trigger: 'blur' }],
        fzr: [{ required: true, message: '专利(软著)负责人不能为空', trigger: 'blur' }],
        xgcy: [{ required: true, message: '专利(软著)成员不能为空', trigger: 'blur' }],
        type: [{ required: true, message: '类型不能为空', trigger: 'blur' }],
      },
      url: {
        add: '/pa/soft/add',
        edit: '/pa/soft/edit',
      },
    }
  },
  created() {},
  watch: {

  },
  methods: {
    add() {
      this.edit({})
    },
    edit(record) {
      this.form.resetFields()
      this.visible = true
      this.model = Object.assign({}, record)
    },

    handleCancel() {
      this.close()
    },
    handleOk() {
      let that = this
      this.$refs.form.validate((valid) => {
        if (valid) {
          that.confirmLoading = true
          //add
          if (!this.model.id) {
            postAction(this.url.add, that.model)
              .then((res) => {
                that.confirmLoading = false
                if (res.success) {
                  that.close()
                  that.$message.success(res.message)
                  that.$emit('ok', res.result)
                  that.close()
                } else {
                  that.$message.warning(res.message)
                }
              })
              .finally(() => {
                that.confirmLoading = false
              })

            //edit
          } else {
            putAction(this.url.edit, that.model)
              .then((res) => {
                that.confirmLoading = false
                if (res.success) {
                  that.close()
                  that.$message.success(res.message)
                  that.$emit('ok', res.result)
                  that.close()
                } else {
                  that.$message.warning(res.message)
                }
              })
              .finally(() => {
                that.confirmLoading = false
              })
          }
        }
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleAddUser() {},
    handleChangeUserCommon(v) {},
  },
}
</script>

<style scoped>
</style>